package com.iohao.mmo.equip.action;

import com.iohao.game.action.skeleton.annotation.ActionController;
import com.iohao.game.action.skeleton.annotation.ActionMethod;
import com.iohao.game.action.skeleton.core.flow.FlowContext;
import com.iohao.game.action.skeleton.protocol.wrapper.StringValue;
import com.iohao.mmo.equip.cmd.EquipCmd;
import com.iohao.mmo.equip.entity.Equip;
import com.iohao.mmo.equip.entity.EquipTemplate;
import com.iohao.mmo.equip.mapper.EquipMapper;
import com.iohao.mmo.equip.mapper.EquipTemplateMapper;
import com.iohao.mmo.equip.proto.EquipMessage;
import com.iohao.mmo.equip.proto.EquipTemplateMessage;
import com.iohao.mmo.equip.service.EquipService;
import com.iohao.mmo.equip.service.EquipTemplateService;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * @author 唐斌
 * @date 2023-07-30
 * @description: 装备属性类
 */
@Slf4j
@Component
@ActionController(EquipCmd.cmd)
public class EquipTemplateAction {

    @Resource
    EquipTemplateService equipTemplateService;

    /**
     * 初始化装备模板
     *
     * @param flowContext flowContext
     */
    @ActionMethod(EquipCmd.initEquipTemplate)
    public void initEquipTemplate(FlowContext flowContext) {
        long userId = flowContext.getUserId();
        // 初始化装备数据，暂时放这
        equipTemplateService.initEquipTemplate();
    }

    /**
     * 获取装备模板信息
     *
     * @param flowContext flowContext
     * @param stringValue 装备模板id
     */
    @ActionMethod(EquipCmd.getEquipTemplate)
    public EquipTemplateMessage getEquipTemplate(FlowContext flowContext, StringValue stringValue) { //参数值
        // 初始化装备数据，暂时放这
        EquipTemplate equipTemplate = equipTemplateService.ofEquip(stringValue.value);
        return EquipTemplateMapper.ME.convert(equipTemplate);
    }

    /**
     * 根据装备模板随机出一件新的装备
     *
     * @param flowContext flowContext
     * @param stringValve 装备模板id
     */
    @ActionMethod(EquipCmd.randomEquip)
    public EquipMessage randomEquip(FlowContext flowContext, StringValue stringValve) { //参数值
        // 初始化装备数据，暂时放这
        Equip equip = equipTemplateService.randomEquip(stringValve.value);
        return EquipMapper.ME.convert(equip);
    }
}
