/*
 * ioGame
 * Copyright (C) 2021 - 2023  渔民小镇 （262610965@qq.com、luoyizhu@gmail.com） . All Rights Reserved.
 * # iohao.com . 渔民小镇
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.iohao.mmo.equip.client;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONWriter;
import com.iohao.game.action.skeleton.protocol.wrapper.StringValue;
import com.iohao.game.external.client.AbstractInputCommandRegion;
import com.iohao.game.external.client.command.InputRequestData;
import com.iohao.game.external.client.kit.ScannerKit;
import com.iohao.mmo.equip.cmd.EquipCmd;
import com.iohao.mmo.equip.proto.EquipMessage;
import com.iohao.mmo.equip.proto.EquipTemplateMessage;
import com.iohao.mmo.equip.proto.OfEquipReq;
import lombok.extern.slf4j.Slf4j;

/**
 * @author 渔民小镇
 * @date 2023-07-30
 */
@Slf4j
public class EquipInputCommandRegion extends AbstractInputCommandRegion {
    @Override
    public void initInputCommand() {
        this.inputCommandCreate.cmd = EquipCmd.cmd;

        request();

        listen();
    }

    private void listen() {

    }

    private void request() {
        InputRequestData inputRequestData;

        // 6-1
        ofCommand(EquipCmd.initEquip).callback(EquipMessage.class, result -> {
            EquipMessage value = result.getValue();
            String jsonFormat = JSON.toJSONString(value, JSONWriter.Feature.PrettyFormat);
        }).setDescription("初始化装备信息");

//        // 动态请求参数（对象）
//        inputRequestData = () -> {
//            ScannerKit.log(() -> log.info("请输入要查询的装备id"));
//            long id = ScannerKit.nextLong(1);
//
//            // 请求参数
//            OfEquipReq ofEquipReq = new OfEquipReq();
//            // 根据装备id获取装备信息
//            ofEquipReq.id = id;
//
//            return ofEquipReq;
//        };

        // 动态请求参数（参数值）
        inputRequestData = () -> {
            ScannerKit.log(() -> log.info("请输入要查询的装备id"));
            String id = ScannerKit.nextLine();

            // 请求参数
            StringValue stringValue = StringValue.of(id);

            return stringValue;
        };

        // 6-2
        ofCommand(EquipCmd.getEquip).callback(EquipMessage.class, result -> {
            EquipMessage value = result.getValue();
            log.info("装备信息 : {}", value);
        }).setDescription("查询装备信息").setInputRequestData(inputRequestData);

        // 6-10
        ofCommand(EquipCmd.initEquipTemplate).callback(EquipTemplateMessage.class, result -> {
            EquipTemplateMessage value = result.getValue();
            log.info("装备模板信息 : {}", value);
        }).setDescription("初始化装备模板");
        // 动态请求参数（参数值）
        inputRequestData = () -> {
            ScannerKit.log(() -> log.info("请输入要查询的装备id"));
            String id = ScannerKit.nextLine();

            // 请求参数
            StringValue stringValue = StringValue.of(id);

            return stringValue;
        };
        // 6-13
        ofCommand(EquipCmd.randomEquip).callback(EquipMessage.class, result -> {
            EquipMessage value = result.getValue();
            log.info("装备信息 : {}", value);
        }).setDescription("根据装备模板随机出一件新的装备").setInputRequestData(inputRequestData);
    }
}